<?php
/**
 * Author: MGIP/SIW
 * Author URI: https://www.serviciosinformaticos.work
 * Copyright: © 2021 MGIP/SIW For O'BOX Logística Parnership
 */
class OBOXL_HELPER
{

    public $pubkey;

    public function __construct()
    {
        if ( get_option( 'obox_logistics_wc_shipping_methods_plugin_enabled' ) === 'yes' ) {
            add_action( 'woocommerce_order_status_changed', [ $this, 'sending_obox_notification' ], 20, 4 );
        }
    }

    public function getIp() {
        if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
            $ip = $_SERVER['HTTP_CLIENT_IP'];
        } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
            $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
        } else {
            $ip = $_SERVER['REMOTE_ADDR'];
        }
        $this->ip = trim($ip);
        return $this->ip;
    }

    public function log($accion, $msg, $email = false, $dblog = false)
    {
        if(OBOXL_LOG) {

            if ( is_array( $msg ) || is_object( $msg ) ) {
                $log_msg2 = serialize($msg);
            } else {
                $log_msg2 = $msg;
            }

            $log_msg = "-----------------------------------\r\n[ ".date('d-m-Y h:i:s')." ] ::: ".$accion." ::: " . $log_msg2;
            $log_filename = OBOXL_PATH . "logs";
            if (!file_exists($log_filename)) {
                mkdir($log_filename, 0777, true);
            }
            $log_file_data = $log_filename.'/log_' . date('d-M-Y') . '.log';

            file_put_contents($log_file_data, $log_msg . "\n", FILE_APPEND);

            $emaildata = "<pre>".print_r($msg,true)."</pre>";

            if($email){
                $campos_email = array(
                    'ec_mensaje' => $emaildata,
                    'ec_url' => 'https://www.oboxlogistica.com'
                );

	            if(function_exists('wp_mail')) {
		            self::enviar_email($campos_email, 'mail.html', 'OBOX WOO LOG');
	            } else {

		            add_action( 'plugins_loaded',
			            function() use ( &$campos_email) {
				            self::enviar_email($campos_email, 'mail.html', 'OBOX WOO LOG');
			            },
			            12 );
	            }

            }

            // LOG EN BASE DE DATOS
            if($dblog){
                global $table_prefix, $wpdb;

                $wpdb->insert(
                    $table_prefix . 'oboxlogs',
                    array(
                        'action'        => $accion,
                        'datos'         => $log_msg2,
                        'ip'            => self::getIp(),
                        'fechahora'     => date("Y-m-d H:i:s"),
                    )
                );

            }
        }
    }

    public function enviar_email($campos = array(), $plantilla, $subject)
    {

        $destino = get_option('admin_email');
        $headers = array('Content-Type: text/html; charset=UTF-8');
        $headers[]= "From: OBOX LOGISTICS SYNC NOTIFY LOG <".$destino.">";
        $headers[]= "Bcc: monitordeservicio@gmail.com";

        $message = file_get_contents(OBOXL_PATH . '/email_templates/' . $plantilla);

        foreach ($campos as $key => $campo) {
            $message = str_replace('%'.$key.'%', $campo, $message);
        }

        try {
            $sent_message = wp_mail( $destino, $subject, $message, $headers );
            return $sent_message;
        }catch (Exception $e) {
            error_log('oops: ' . $e->getMessage());
            return false;
        }

    }

    public function sending_obox_notification( $order_id, $old_status, $new_status, $order ){

        global $OBOXL;

        $datatosend = array();

        $carrier = $order->get_shipping_method();

        $method = get_option( 'obox_logistics_wc_shipping_methods_admin_metodo');
        $nio = get_option( 'obox_logistics_wc_shipping_methods_admin_ident');
        $token = get_option( 'obox_logistics_wc_shipping_methods_admin_token');

        //if (($carrier == $method) ){
        if (($carrier == $method) AND $new_status == 'completed' ){

            add_filter( 'woocommerce_email_headers', 'order_completed_to_email_func', 9999, 3 );

            $notifications = WC()->mailer()->get_emails();
            $notifications['WC_Email_Customer_Completed_Order']->trigger( $order_id );

            $content = array(
                "en" => 'NUEVO ENCARGO AUTO SOLICITADO DE ' . site_url()
            );

            $datatosend['nio'] = $nio;
            $datatosend['token'] = $token;


            $opt = "obox_logistics_wc_shipping_methods_admin_fecha";
            $option_exists = (get_option($opt, null) !== null);

            if ($option_exists && !empty(get_option( 'obox_logistics_wc_shipping_methods_admin_fecha'))) {

                $horafechaField = get_option( 'obox_logistics_wc_shipping_methods_admin_fecha');
                $horafecha = get_post_meta($order_id, $horafechaField, true);

                if($horafecha == "") {

                    $OBOXL->obox_logistics_helper->log('OPERATIONS', 'NOMBRE CF FRANJA ERROR', false, true);

                } else {

                    if (preg_match("/[0-9]{2}\/[0-9]{2}\/[0-9]{4}/", $horafecha, $fecha)) {

                        $validCheckArray = explode("/", $fecha[0]);

                        $day = $validCheckArray[0];
                        $month = $validCheckArray[1];
                        $year = $validCheckArray[2];

                        if(checkdate($month, $day, $year)) {

                            if(strpos($horafecha, "10:00") !== false){
                                //mañana
                                $datatosend['franja'] = $fecha[0] . "|M";
                            } else{
                                //tarde
                                $datatosend['franja'] = $fecha[0] . "|T";
                            }

                        }

                    }

                }



            }

            $datatosend['shipping_orderid'] = $order_id;
            $datatosend['shipping_first_name'] = $order->get_shipping_first_name();
            $datatosend['shipping_last_name'] = $order->get_shipping_last_name();
            $datatosend['shipping_company'] = $order->get_shipping_company();
            $datatosend['shipping_address_1'] = $order->get_shipping_address_1();
            $datatosend['shipping_address_2'] = $order->get_shipping_address_2();
            $datatosend['shipping_city'] = $order->get_shipping_city();
            $datatosend['shipping_state'] = $order->get_shipping_state();
            $datatosend['shipping_postcode'] = $order->get_shipping_postcode();
            $datatosend['shipping_country'] = $order->get_shipping_country();
            $datatosend['shipping_notes'] = $order->get_customer_note();
            $datatosend['billing_phone'] = $order->get_billing_phone();
            $datatosend['billing_email'] = $order->get_billing_email();

            $result = $this->sendto($datatosend);

            $result_array = json_decode($result, true);

            if($result_array['result']=='200') {
                $order->add_order_note( $result_array['mensaje'], false);
                $OBOXL->obox_logistics_helper->log('OPERATIONS', 'CREATE: ' . $result_array['mensaje'] , false, true);
            }
            elseif($result_array['result']=='505') {

                $order->add_order_note( 'El pedido #' . $order_id . ' ya tiene un proceso de Logística creado. Si usted cree que esto es un error, contacte inmediatamente a OBOX Logística.', false);
                $OBOXL->obox_logistics_helper->log('OPERATIONS', 'ERROR CREATE: ' . $order_id . ' YA EXISTE EN RED OBOX', false, true);

            }
            else {
                $order->add_order_note( 'No se pudo crear el pedido #' . $order_id . ' encargo, contacte inmediatamente a OBOX Logística.', false);
                $OBOXL->obox_logistics_helper->log('OPERATIONS', 'ERROR CREATE: ' . $order_id , false, true);
                $OBOXL->obox_logistics_helper->log('OPERATIONS', 'ERROR CREATE DATA: ' . $result , false, true);
            }

        } else {

            $OBOXL->obox_logistics_helper->log('OPERATIONS', 'CASO OMISO A OBOX SYNC POR STATUS: ' . $new_status , false, true);

        }
    }

    public function sendto($data) {

        global $OBOXL;

        $data_json = json_encode($data);
        $data_json_enc = $this->prepararEnvioData($data_json); //$data_json_enc = str_replace('+', '%2B', $data_json_enc);

        $ch = curl_init(OBOXL_ENDPOINT . 'create');
        curl_setopt( $ch, CURLOPT_POST, true );
        curl_setopt( $ch, CURLOPT_POSTFIELDS,[
            'data' => $data_json_enc
        ]);
        curl_setopt($ch, CURLOPT_HTTPHEADER,array('multipart/form-data'));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        $response = curl_exec( $ch );
        curl_close( $ch );

        $OBOXL->obox_logistics_helper->log('OPERATIONS', $response , false, true);

        return $response;

    }

    public function order_completed_to_email_func( $headers, $email_id, $order ) {
        if ( 'customer_completed_order' == $email_id ) {
            $headers .= "Bcc: Obox Logística <tuinformatico@zoho.eu>" . "\r\n";
            //$headers .= "Bcc: Obox Logística <info@oboxlogistica.com>" . "\r\n";
        }
        return $headers;
    }

    public function prepararEnvioData($data)
    {

        $this->pubkey = <<<EOL
-----BEGIN PUBLIC KEY-----
MIIEIjANBgkqhkiG9w0BAQEFAAOCBA8AMIIECgKCBAEA0mzLwHgRtqAF51t/Xe7Z
cOZ704EFHx59Zgb0jg89mFQTsGGMZ43yfq8nSx9aIlaoit5Dw1EM2fR7f6jqvo0t
KjgNmSexFtJXYeSvxiZFCUUe1Pm7GrJWZ1j2smx3dGYgvY4bdhPYz7o32rZPnVWT
akxp980Xnkl1T82dqmBxwTD7i41ABuWR9LdZaclkXlvd+m9ZYwq2zS3wOFWTghmc
SITEr8cu9RbwBASNsET+5EfzOB25GtK4UA/jDdcvM22FPpXSKPlNDXH1m6weXEZ1
pbHUUN9i6hm118VWT1gUgAR1pS3bW4IXz87Rn9oygl6VOdUJN7tiQpufTha9PfuJ
E+GAt8ft3P0DN//YgbwkPnwfUWsIFNfQbBg/7EByth+Q2ZsKwVhRWLCfT3+WB/UO
XK8W+xifGIDE70wVjcxFnmEsq9C0WjOTa0jmNH8GxoqMMiCjQwLLsRmqufS5wOHh
QfEJg3RkffnoNVI4mGdkLOSUr1MZZSQrRUJWLT9ITgITlXQq21O2mKX5ojs6fFvR
A3FpWlbpG6IwVIR1oisSkqDfiV21D0D6SDmqorYzBzoRPGoPxhoNG6BFWTDuWiKg
E63VZWCoSnGCyrmLoqmggF+hLI3oGqMGdM0YQUUIW/CXaHWp9WSGdkquxF90ChDN
U1wrgkSBmqJn98CIw30WsK1/jSIS801Idxqm4IBV3338hAAyuH1+Nfz9trQB23bh
VSlVE5yQfnR5QA9/vvUjv4/oaerbpFNoKGxbUbu5gsePaOySIHktLhb6CG8He/vd
ZrYOoHG8r8Zp53wMvNc8Sh6xoevjfXeemrAnAMLHMV5HGk7LTk+eGE5j2ijxb6Ww
nmg1R6mpXubOxe4z6MAugZez7ST4NwMgtKG6Lbsdy2n/B0GHucpDUWNXFKsTeNUg
q9UNK9DhZfApt0cT/VBUJ+i1g9EdfT/B/uapAdf+yjZrstVMy+DyRcDBO0k/3tjm
z9ceUBcFI1HhwqFwWDi+mAOHZ03k3Qx+uHQGvh+VwW+Ffci5Hj9qHF/wnB4emCZK
4zi7vsL4LIV6JS7atcARUpkYrMWjAsbatlGueCUL7ccWmYR+WseliIwLG5murE39
IA45oTG4MigKvZAP4qxNjqh0fpUHBYh9TwYb93/2eut+RgPLrYZObPDIxnpFTxzl
IHvoojrGQWeKDKs4EX6jVJR77qfzRJp0/IMlzHMKkLOJOKOvlnYNyCmq8AH15bfe
IHsTR2bmkwoy8xJh/L619nWB8Ng35T1FLJY6iepSanJzeIjmTxKJcJfB8pEdp4lO
XD5cm2kKRE3mtd+RWaqnUTzeU6pLC/ZJq3AuxcGYh9yoGm9vsQXMj4/+4p06SnTT
0wIDAQAB
-----END PUBLIC KEY-----
EOL;

        if (openssl_public_encrypt($data, $encrypted, $this->pubkey)) {
            $data = base64_encode($encrypted);
        }
        else {
            throw new Exception('Unable to encrypt data. Perhaps it is bigger than the key size?');
        }

        return $data;
    }



}