<?php
/**
 * Author: MGIP/SIW
 * Author URI: https://www.serviciosinformaticos.work
 * Copyright: © 2021 MGIP/SIW For O'BOX Logística Parnership
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'OBOX_Logistics_WC_Settings_Shipping_Methods' ) ) :

    class OBOX_Logistics_WC_Settings_Shipping_Methods extends WC_Settings_Page {

        public function __construct() {

            $this->id    = 'obox_logistics_wc_shipping_methods';
            $this->label = 'O\'BOX Logística';

            parent::__construct();

            add_filter( 'woocommerce_admin_settings_sanitize_option', array( $this, 'maybe_unsanitize_option' ), PHP_INT_MAX, 3 );

            require_once OBOXL_PATH . 'classes/wc-settings-section.php';
            require_once OBOXL_PATH . 'classes/wc-settings-general.php';

        }

        public function maybe_unsanitize_option( $value, $option, $raw_value ) {
            return ( ! empty( $option['obox_logistics_wc_csm_raw'] ) ? $raw_value : $value );
        }

        public function get_settings() {
            global $current_section;
            return array_merge(
                apply_filters( 'woocommerce_get_settings_' . $this->id . '_' . $current_section, array() ),
                array()
            );
        }

        public function validar_token() {
            global $current_section, $OBOXL;
            if (get_option( 'obox_logistics_wc_shipping_methods_plugin_enabled' ) == 'yes' &&
                get_option( 'obox_logistics_wc_shipping_methods_admin_ident' ) &&
                get_option( 'obox_logistics_wc_shipping_methods_admin_token' )) {

                $ident = get_option( 'obox_logistics_wc_shipping_methods_admin_ident' );
                $token = get_option( 'obox_logistics_wc_shipping_methods_admin_token' );

                $ch = curl_init(OBOXL_ENDPOINT . 'check');
                curl_setopt( $ch, CURLOPT_POST, true );
                curl_setopt( $ch, CURLOPT_POSTFIELDS,[
                    "NIO"=>$ident,
                    "TOKEN"=>$token,
                ]);
                curl_setopt($ch, CURLOPT_HTTPHEADER,array('multipart/form-data'));
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                $hello = curl_exec( $ch );
                curl_close( $ch );

                $hello = json_decode($hello, true);

                if(count($hello['data']) > 0 ) {
                    add_action( 'admin_notices', array( $this, 'admin_notice_settings_ok' ) );
                    $OBOXL->obox_logistics_helper->log('OPERATIONS', 'Validación OK: '. $hello, false, true);
                } else {
                    add_action( 'admin_notices', array( $this, 'admin_notice_settings_ko' ) );
                    update_option( 'obox_logistics_wc_shipping_methods_plugin_enabled', 'no' );
                    $OBOXL->obox_logistics_helper->log('OPERATIONS', 'Error validar_token(): '. $hello, false, true);
                }

            }

        }

        public function admin_notice_settings_ok() {
            echo '<div class="notice notice-success is-dismissible"><p><strong>Autenticación Aceptada. Bienvenid@ a la Red O\'BOX Logistics</strong></p></div>';
        }

        public function admin_notice_settings_ko() {
            echo '<div class="notice notice-warning is-dismissible"><p><strong>Autenticación Invalida. Intente nuevamente o contáctenos</strong></p></div>';
        }

        public function save() {
            parent::save();
            $this->validar_token();
        }
    }

    return new OBOX_Logistics_WC_Settings_Shipping_Methods();

endif;