<?php
/**
 * Author: MGIP/SIW
 * Author URI: https://www.serviciosinformaticos.work
 * Copyright: © 2021 MGIP/SIW For O'BOX Logística Parnership
 */
class OBOX_Plugin {

    public $plugin_name;
    public $version;
    public $obox_logistics_helper;

    public function __construct( $plugin_name, $version ) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        if (!$this->is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
            add_action( 'admin_notices', array( $this, 'admin_notice_woo_off' ) );
        }

        $this->load_dependencies();
        $this->define_scripts();
        $this->define_wp_actions();
        $this->define_wp_filters();

        $this->obox_logistics_helper = new OBOXL_HELPER();

    }

    public function get_plugin_name() {
        return $this->plugin_name;
    }

    public function get_version() {
        return $this->version;
    }

    public function admin_notice($message, $type) { ?>
        <div class="alert alert-<?php echo $type; ?> alert-dismissible fade show" role="alert">
            <?php echo($message); ?>
            <button type="button" class="close" data-dismiss="alert" aria-label="Cerrar">
                <span aria-hidden="true">&times;</span>
            </button>
        </div>
        <?php
    }

    public function admin_notice_woo_off() {
        echo '<div class="notice notice-warning is-dismissible"><p><strong>Woocommerce debe de esar activo para utilizar la sincronización de O\'BOX Logistics</strong></p></div>';
    }

    public function admin_notice_general($mensaje) {
        echo '<div class="notice notice-success is-dismissible"><p><pre>' . $mensaje . '</pre></div>';
    }

    public function load_dependencies() {

        require_once OBOXL_PATH . 'classes/helper.php';

    }

    public function define_scripts() {

        add_action( 'wp_enqueue_scripts',                   array( $this, 'obox_logistics_enqueue_styles' ), 10 );
        add_action( 'wp_enqueue_scripts',                   array( $this, 'obox_logistics_enqueue_scripts' ), 10 );

        add_action( 'admin_enqueue_scripts',                array( $this, 'admin_obox_logistics_enqueue_scripts' ), 10, 1 );
        add_action( 'admin_enqueue_scripts',                array( $this, 'admin_obox_logistics_enqueue_styles' ), 10, 1 );

        add_action( 'wp_head',                              array($this, 'func_header_includes_scripts' ));
        add_action( 'wp_footer',                            array($this, 'func_footer_includes_scripts' ));

    }

    public function define_wp_filters() {

        if ( is_admin() ) {
            add_filter( 'plugin_action_links_' . OBOXL_BASENAME, array( $this, 'action_links' ) );
            add_filter( 'woocommerce_get_settings_pages', array( $this, 'add_woocommerce_settings_tab' ) );
        }

    }

    public function action_links( $links ) {
        $custom_links   = array();

        if ($this->is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
            $custom_links[] = '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=obox_logistics_wc_shipping_methods' ) . '">Ajustes</a>';
        } else {
            $custom_links[] = '<a href="' . admin_url( 'plugin-install.php?s=Woocommerce&tab=search&type=term' ) . '">Instalar Woocommerce</a>';
        }

        $custom_links[] = '<a target="_blank" href="https://www.oboxlogistica.com">Visitar Sitio Web</a>';
        return array_merge( $custom_links, $links );
    }

    public function add_woocommerce_settings_tab( $settings ) {
        $settings[] = require_once OBOXL_PATH . 'classes/wc-settings.php';
        return $settings;
    }

    public function is_plugin_active( $plugin ) {
        return ( function_exists( 'is_plugin_active' ) ? is_plugin_active( $plugin ) :
            (
                in_array( $plugin, apply_filters( 'active_plugins', (array) get_option( 'active_plugins', array() ) ), true ) ||
                ( is_multisite() && array_key_exists( $plugin, (array) get_site_option( 'active_sitewide_plugins', array() ) ) )
            )
        );
    }


    public function define_wp_actions() {



    }

    public function obox_logistics_enqueue_scripts() {

        wp_enqueue_script( $this->plugin_name . '-obox_logistics_front_js',
            OBOXL_URL . 'assets/js/runtime.js',
            array( 'jquery' ),
            $this->version,
            true,
        );

    }

    public function admin_obox_logistics_enqueue_scripts() {

        wp_enqueue_script($this->plugin_name . '-obox_logistics_admin_js',
            OBOXL_URL . 'assets/js/runtime-admin.js',
            array( 'jquery' ),
            $this->version,
            false );
    }

    public function func_header_includes_scripts() { ?>

        <script>
            jQuery(document).ready(function( $ ) {
            });

        </script>

    <?php }

    public function func_footer_includes_scripts() { ?>

        <script>
            jQuery(document).ready(function( $ ) {
            });

        </script>

    <?php }

}